/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.client.internal.ReportClient");

dojo.require("com.ibm.rational.report.web.core.client.internal.SessionManager");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
dojo.require("com.ibm.team.process.web.client.projectarea");

var SessionManager			= com.ibm.rational.report.web.core.client.internal.SessionManager;
var session					= com.ibm.team.repository.web.client.session;
var ServiceRequest 			= com.ibm.team.repository.web.transport.ServiceRequest;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var TeamServerClient 		= com.ibm.team.repository.web.transport.TeamServerClient;

/**
 * Manages report REST service calls.
 */
com.ibm.rational.report.web.core.client.internal.ReportClient = {

	REPORT_SERVICE_URI: "com.ibm.rational.report.common.IReportRestService",
	
	REPORT_CATEGORIZATION_SERVICE_URI: "com.ibm.rational.report.common.IReportCategorizationRestService",	
	
	getProductVersion: function(responseHandler) {
		this._invokeReportService(responseHandler, "getProductVersion", null);
	},

	getAllReports: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getAllReports", args);
	},
	
	getReport: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReport", args);
	},
	
	postDeleteReports: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postDeleteReports", args);
	},
	
	getAllReportDesigns: function(responseHandler) {
		this._invokeReportService(responseHandler, "getAllReportDesigns", null);
	},
	
	getReportDesignsPage: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportDesignsPage", args);
	},
	
	getReportDesigns: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportDesigns", args);
	},
	
	getReportDesign: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportDesign", args);
	},
	
	postNewReportDesign: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postNewReportDesign", args);
	},
	
	postUpdateReportDesign: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postUpdateReportDesign", args);
	},
	
	postDeleteReportDesign: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postDeleteReportDesign", args);
	},
	
	getAllReportQueries: function(responseHandler) {
		this._invokeReportService(responseHandler, "getAllReportQueries", null);
	},
	
	getReportQueriesPage: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportQueriesPage", args);
	},
	
	getReportQueries: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportQueries", args);
	},
	
	getReportQuery: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportQuery", args);
	},
	
	postNewReportQuery: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postNewReportQuery", args);
	},
	
	postUpdateReportQuery: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postUpdateReportQuery", args);
	},
	
	postDeleteReportQuery: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postDeleteReportQuery", args);
	},
	
	getAllReportSnapshots: function(responseHandler) {
		this._invokeReportService(responseHandler, "getAllReportSnapshots", null);
	},
	
	getReportSnapshotsPage: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportSnapshotsPage", args);
	},
	
	getReportSnapshots: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportSnapshots", args);
	},
	
	getReportSnapshot: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportSnapshot", args);
	},
	
	postNewReportSnapshot: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postNewReportSnapshot", args);
	},
	
	postUpdateReportSnapshot: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postUpdateReportSnapshot", args);
	},
	
	postDeleteReportSnapshot: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postDeleteReportSnapshot", args);
	},

	// Gets the rendered report for a given report design
	getRenderedReport: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getRenderedReport", args);
	},
	
	// Sends a report via email
	postEmailReport: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postEmailReport", args);
	},
	
	// Exports a report as a document
	postExportReport: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "postExportReport", args);
	},
	
	getReportParameterDefs: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportParameterDefs", args);
	},
	
	getReportParameterValues: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getReportParameterValues", args);
	},
	
	getCascadingParameterValues: function(responseHandler, args) {
		this._invokeReportService(responseHandler, "getCascadingParameterValues", args);
	},
	
	getReportDesignExistsInServer: function(responseHandler, args){
		this._invokeReportService(responseHandler, "getReportDesignExistsInServer", args);
	},
	
	getRootReportTreeFolders: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "getRootReportTreeFolders", args);
	},
	
	getReportTreeNodes: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "getReportTreeNodes", args);
	},
	
	postNewReportTreeFolder: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postNewReportTreeFolder", args);
	},	
	
	postNewReportTreeNode: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postNewReportTreeNode", args);
	},
	
	postNewReportTreeNodes: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postNewReportTreeNodes", args);
	},	
	
	postUpdateReportTreeFolder: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postUpdateReportTreeFolder", args);
	},
	
	postUpdateReportTreeNode: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postUpdateReportTreeNode", args);
	},
	
	postDeleteReportTreeNode: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postDeleteReportTreeNode", args);
	},

	postDeleteReportTreeNodes: function(responseHandler, args) {
		this._invokeReportCategorizationService(responseHandler, "postDeleteReportTreeNodes", args);
	},
	/**
	 * Invokes the requested method on the report REST service.
	 */
	_invokeReportService: function(responseHandler, method, args) {
		var serviceRequest;
		if (arguments.length == 2) {
			serviceRequest= new ServiceRequest(this.REPORT_SERVICE_URI,	method);
		} else {
			serviceRequest = new ServiceRequest(this.REPORT_SERVICE_URI, method, args);
		}
		TeamServerClient.invokeService(serviceRequest, responseHandler);
		SessionManager.resetTimeOut();
	},
	
	/**
	 * Invokes the requested method on the report categorization REST service.
	 */
	_invokeReportCategorizationService: function(responseHandler, method, args) {
		var serviceRequest;
		if (arguments.length == 2) {
			serviceRequest = new ServiceRequest(this.REPORT_CATEGORIZATION_SERVICE_URI,	method);
		} else {
			serviceRequest = new ServiceRequest(this.REPORT_CATEGORIZATION_SERVICE_URI,	method, args);
		}
		TeamServerClient.invokeService(serviceRequest, responseHandler);
		SessionManager.resetTimeOut();
	}
	
};

})();